==> jc-1.4.0.tar.gz: soot/tagkit/LongConstantValueTag.h <==
// public class soot.tagkit.LongConstantValueTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 927f75e1f2873cee soot_tagkit_ConstantValueTag
// @dep_class 91b7ee1403e19066 soot_tagkit_LongConstantValueTag

// header file dependencies
// @dep_header soot_tagkit_ConstantValueTag

#include "soot/tagkit/ConstantValueTag.h"

#ifndef _JC_soot_tagkit_LongConstantValueTag_H_
#define _JC_soot_tagkit_LongConstantValueTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_tagkit_LongConstantValueTag$sub_refs	_jc_soot_tagkit_LongConstantValueTag$sub_refs;
typedef struct _jc_soot_tagkit_LongConstantValueTag$sub_nonrefs	_jc_soot_tagkit_LongConstantValueTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_LongConstantValueTag$refs	_jc_soot_tagkit_LongConstantValueTag$refs;
typedef struct _jc_soot_tagkit_LongConstantValueTag$nonrefs	_jc_soot_tagkit_LongConstantValueTag$nonrefs;
typedef struct _jc_soot_tagkit_LongConstantValueTag$object	_jc_soot_tagkit_LongConstantValueTag$object;

typedef const struct _jc_soot_tagkit_LongConstantValueTag$vmethods	_jc_soot_tagkit_LongConstantValueTag$vmethods;
typedef const struct _jc_soot_tagkit_LongConstantValueTag$vtable	_jc_soot_tagkit_LongConstantValueTag$vtable;
typedef const struct _jc_soot_tagkit_LongConstantValueTag$vtype	_jc_soot_tagkit_LongConstantValueTag$vtype;

// Constructors
extern void _jc_soot_tagkit_LongConstantValueTag$method$_init$8de6a0a3bec04d2a(_jc_env *, struct _jc_soot_tagkit_LongConstantValueTag$object *, jlong);

// Virtual methods
extern jlong _jc_soot_tagkit_LongConstantValueTag$method$getLongValue$0ab9b65232b8743c(_jc_env *, struct _jc_soot_tagkit_LongConstantValueTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_LongConstantValueTag$method_info$getLongValue$0ab9b65232b8743c;

// Virtual methods structure
struct _jc_soot_tagkit_LongConstantValueTag$vmethods {
	jlong	(*getLongValue$0ab9b65232b8743c)(_jc_env *, struct _jc_soot_tagkit_LongConstantValueTag$object *);
};

// Vtable
struct _jc_soot_tagkit_LongConstantValueTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_ConstantValueTag$vmethods	soot_tagkit_ConstantValueTag;
	_jc_soot_tagkit_LongConstantValueTag$vmethods	soot_tagkit_LongConstantValueTag;
};

// Vtype
struct _jc_soot_tagkit_LongConstantValueTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_LongConstantValueTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_LongConstantValueTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_LongConstantValueTag$refs {
    _jc_soot_tagkit_LongConstantValueTag$sub_refs	soot_tagkit_LongConstantValueTag;
    _jc_soot_tagkit_ConstantValueTag$sub_refs	soot_tagkit_ConstantValueTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_LongConstantValueTag$sub_nonrefs {
	jlong	value;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_LongConstantValueTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_ConstantValueTag$sub_nonrefs	soot_tagkit_ConstantValueTag;
    _jc_soot_tagkit_LongConstantValueTag$sub_nonrefs	soot_tagkit_LongConstantValueTag;
};

// Object instance structure
struct _jc_soot_tagkit_LongConstantValueTag$object {
	_jc_soot_tagkit_LongConstantValueTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_LongConstantValueTag$vtype	*vtype;
	_jc_soot_tagkit_LongConstantValueTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_LongConstantValueTag$vtype _jc_soot_tagkit_LongConstantValueTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_LongConstantValueTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_LongConstantValueTag$class_object;

#endif	/* _JC_soot_tagkit_LongConstantValueTag_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/LongConstantValueTag.h <==
// public class soot.tagkit.LongConstantValueTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 927f75e1f2873cee soot_tagkit_ConstantValueTag
// @dep_class 91b7ee1403e19066 soot_tagkit_LongConstantValueTag

// header file dependencies
// @dep_header soot_tagkit_ConstantValueTag

#include "soot/tagkit/ConstantValueTag.h"

#ifndef _JC_soot_tagkit_LongConstantValueTag_H_
#define _JC_soot_tagkit_LongConstantValueTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_tagkit_LongConstantValueTag$sub_refs	_jc_soot_tagkit_LongConstantValueTag$sub_refs;
typedef struct _jc_soot_tagkit_LongConstantValueTag$sub_nonrefs	_jc_soot_tagkit_LongConstantValueTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_LongConstantValueTag$refs	_jc_soot_tagkit_LongConstantValueTag$refs;
typedef struct _jc_soot_tagkit_LongConstantValueTag$nonrefs	_jc_soot_tagkit_LongConstantValueTag$nonrefs;
typedef struct _jc_soot_tagkit_LongConstantValueTag$object	_jc_soot_tagkit_LongConstantValueTag$object;

typedef const struct _jc_soot_tagkit_LongConstantValueTag$vmethods	_jc_soot_tagkit_LongConstantValueTag$vmethods;
typedef const struct _jc_soot_tagkit_LongConstantValueTag$vtable	_jc_soot_tagkit_LongConstantValueTag$vtable;
typedef const struct _jc_soot_tagkit_LongConstantValueTag$vtype	_jc_soot_tagkit_LongConstantValueTag$vtype;

// Constructors
extern void _jc_soot_tagkit_LongConstantValueTag$method$_init$8de6a0a3bec04d2a(_jc_env *, struct _jc_soot_tagkit_LongConstantValueTag$object *, jlong) _JC_JCNI_ATTR;

// Virtual methods
extern jlong _jc_soot_tagkit_LongConstantValueTag$method$getLongValue$0ab9b65232b8743c(_jc_env *, struct _jc_soot_tagkit_LongConstantValueTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_LongConstantValueTag$method_info$getLongValue$0ab9b65232b8743c;

// Virtual methods structure
struct _jc_soot_tagkit_LongConstantValueTag$vmethods {
	jlong	(*getLongValue$0ab9b65232b8743c)(_jc_env *, struct _jc_soot_tagkit_LongConstantValueTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_LongConstantValueTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_ConstantValueTag$vmethods	soot_tagkit_ConstantValueTag;
	_jc_soot_tagkit_LongConstantValueTag$vmethods	soot_tagkit_LongConstantValueTag;
};

// Vtype
struct _jc_soot_tagkit_LongConstantValueTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_LongConstantValueTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_LongConstantValueTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_LongConstantValueTag$refs {
    _jc_soot_tagkit_LongConstantValueTag$sub_refs	soot_tagkit_LongConstantValueTag;
    _jc_soot_tagkit_ConstantValueTag$sub_refs	soot_tagkit_ConstantValueTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_LongConstantValueTag$sub_nonrefs {
	jlong	value;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_LongConstantValueTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_ConstantValueTag$sub_nonrefs	soot_tagkit_ConstantValueTag;
    _jc_soot_tagkit_LongConstantValueTag$sub_nonrefs	soot_tagkit_LongConstantValueTag;
};

// Object instance structure
struct _jc_soot_tagkit_LongConstantValueTag$object {
	_jc_soot_tagkit_LongConstantValueTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_LongConstantValueTag$vtype	*vtype;
	_jc_soot_tagkit_LongConstantValueTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_LongConstantValueTag$vtype _jc_soot_tagkit_LongConstantValueTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_LongConstantValueTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_LongConstantValueTag$class_object;

#endif	/* _JC_soot_tagkit_LongConstantValueTag_H_ */
